has_attribute_table

Function has_attribute_table 

pub fn has_attribute_table() -> bool
Whether some attribute handler is attached to igraph (igraph_has_attribute_table).

This is true after enable, but also when a handler was attached through the raw FFI.