pub type BooleanCombineFn = unsafe extern "C" fn(input: *const igraph_vector_bool_t, output: *mut igraph_bool_t) -> igraph_error_t;Expand description
Signature of a boolean combination function of the C attribute handler.
pub type BooleanCombineFn = unsafe extern "C" fn(input: *const igraph_vector_bool_t, output: *mut igraph_bool_t) -> igraph_error_t;Signature of a boolean combination function of the C attribute handler.