pub fn has_attribute_table() -> boolExpand description
Whether some attribute handler is attached to igraph
(igraph_has_attribute_table).
This is true after enable, but also when a handler was attached
through the raw FFI.
pub fn has_attribute_table() -> boolWhether some attribute handler is attached to igraph
(igraph_has_attribute_table).
This is true after enable, but also when a handler was attached
through the raw FFI.