pub type NumericCombineFn = unsafe extern "C" fn(input: *const igraph_vector_t, output: *mut igraph_real_t) -> igraph_error_t;Expand description
Signature of a numeric combination function of the C attribute handler:
input holds the values of the merged elements, the result goes to output.